@@ -210,6 +210,18 @@ def properties_callback(ctx, param, value):
     return inputs_to_dict(value, dot_hierarchy=True, deleting=deleting)
 
 
+def parse_on_off(ctx, param, value):
+    if value is None or ctx.resilient_parsing:
+        return
+    if value.lower() == 'off':
+        return False
+    elif value.lower() == 'on':
+        return True
+    else:
+        raise CloudifyValidationError(
+            'Value must be on/off, but got: {0}'.format(value))
+
+
 def parse_and_validate_labels(ctx, param, value):
     if value is None or ctx.resilient_parsing:
         return
@@ -909,6 +921,11 @@ class Options(object):
             required=False,
             help=helptexts.PROFILE_NAME)
 
+        self.profile_manager_ip = click.option(
+            '-m', '--manager-ip',
+            help=helptexts.PROFILE_MANAGER_IP,
+        )
+
         self.manager_username = click.option(
             '-u',
             '--manager-username',
@@ -980,7 +997,7 @@ class Options(object):
             '--ssl',
             required=False,
             help=helptexts.SSL_STATE,
-            callback=validate_name
+            callback=parse_on_off,
         )
 
         self.ssh_port = click.option(
