@@ -184,7 +184,7 @@ ASYNC_UPLOAD = (
     "blueprints list` commands."
 )
 
-MANAGEMENT_IP = 'The IP of the manager host machine'
+PROFILE_MANAGER_IP = 'The address of the Manager'
 SSH_USER = 'The SSH user on the manager host machine'
 SSH_KEY = 'The path to the ssh key-file to use when connecting'
 SSH_PORT = 'The SSH port to use when connecting to the manager'
