@@ -193,7 +193,8 @@ def use(manager_ip,
             **kwargs)
     if not env.profile.manager_username:
         return
-    _update_cluster_profile_to_dict(logger)
+    if not skip_credentials_validation:
+        _update_cluster_profile_to_dict(logger)
 
 
 def _update_cluster_profile_to_dict(logger):
@@ -213,13 +214,13 @@ def _switch_profile(manager_ip, profile_name, logger, **kwargs):
     provided_options = [key for key, value in kwargs.items() if value]
 
     if any(provided_options):
-        logger.warning('Profile {0} already exists. '
-                       'The passed in options are ignored: {1}. '
-                       'To update the profile, use `cfy profiles set`'
-                       .format(profile_name, ', '.join(provided_options)))
+        logger.warning('Profile %s already exists. '
+                       'The passed in options are ignored: %s. '
+                       'To update the profile, use `cfy profiles set`',
+                       profile_name, ', '.join(provided_options))
 
     env.set_active_profile(profile_name)
-    logger.info('Using manager {0}'.format(profile_name))
+    logger.info('Using manager %s', profile_name)
 
 
 def _create_profile(
@@ -248,9 +249,8 @@ def _create_profile(
     # kerberos_env default is `False` and not `None`
     kerberos_env = get_kerberos_indication(kerberos_env) or False
 
-    logger.info('Attempting to connect to {0} through port {1}, using {2} '
-                '(SSL mode: {3})...'.format(manager_ip, rest_port,
-                                            rest_protocol, ssl))
+    logger.info('Attempting to connect to %s through port %s, using %s '
+                '(SSL mode: %s)...', manager_ip, rest_port, rest_protocol, ssl)
 
     # First, attempt to get the provider from the manager - should it fail,
     # the manager's profile directory won't be created
@@ -267,8 +267,7 @@ def _create_profile(
         skip_credentials_validation
     )
     init.init_manager_profile(profile_name=profile_name)
-    logger.info('Using manager {0} with port {1}'.format(
-        manager_ip, rest_port))
+    logger.info('Using manager %s with port %s', manager_ip, rest_port)
     _set_profile_context(
         profile_name,
         provider_context,
@@ -297,7 +296,7 @@ def delete(profile_name, logger):
 
     `PROFILE_NAME` is the IP of the manager the profile manages.
     """
-    logger.info('Deleting profile {0}...'.format(profile_name))
+    logger.info('Deleting profile %s...', profile_name)
     if not env.is_profile_exists(profile_name):
         raise CloudifyCliError('Profile {0} does not exist'
                                .format(profile_name))
@@ -305,91 +304,6 @@ def delete(profile_name, logger):
     logger.info('Profile deleted')
 
 
-def set_profile(profile_name,
-                manager_username,
-                manager_password,
-                manager_tenant,
-                ssh_user,
-                ssh_key,
-                ssh_port,
-                ssl,
-                rest_certificate,
-                rest_port,
-                kerberos_env,
-                skip_credentials_validation,
-                logger):
-    """Set the profile name, manager username and/or password and/or tenant
-    and/or ssl state (on/off) in the *current* profile
-    """
-    if not any([profile_name, ssh_user, ssh_key, ssh_port, manager_username,
-                manager_password, manager_tenant, ssl is not None,
-                rest_certificate, kerberos_env is not None]):
-        raise CloudifyCliError(
-            "You must supply at least one of the following:  "
-            "profile name, username, password, tenant, "
-            "ssl, rest certificate, ssh user, ssh key, ssh port, kerberos env")
-    username = manager_username or env.get_username()
-    password = manager_password or env.get_password()
-    tenant = manager_tenant or env.get_tenant_name()
-    protocol, port = _get_ssl_protocol_and_port(ssl)
-    if rest_port is not None:
-        port = rest_port
-
-    if not skip_credentials_validation:
-        _validate_credentials(username,
-                              password,
-                              tenant,
-                              rest_certificate,
-                              protocol,
-                              port,
-                              kerberos_env)
-    old_name = None
-    if profile_name:
-        if profile_name == 'local':
-            raise CloudifyCliError('Cannot use the reserved name "local"')
-        if env.is_profile_exists(profile_name):
-            raise CloudifyCliError('Profile {0} already exists'
-                                   .format(profile_name))
-        old_name = env.profile.profile_name
-        env.profile.profile_name = profile_name
-    if manager_username:
-        logger.info('Setting username to `{0}`'.format(manager_username))
-        env.profile.manager_username = manager_username
-    if manager_password:
-        logger.info('Setting password to `{0}`'.format(manager_password))
-        env.profile.manager_password = manager_password
-    if manager_tenant:
-        logger.info('Setting tenant to `{0}`'.format(manager_tenant))
-        env.profile.manager_tenant = manager_tenant
-    if rest_certificate:
-        logger.info(
-            'Setting rest certificate to `{0}`'.format(rest_certificate))
-        env.profile.rest_certificate = rest_certificate
-    if rest_port:
-        logger.info('Setting rest port to `{0}'.format(rest_port))
-        env.profile.rest_port = rest_port
-    if ssh_user:
-        logger.info('Setting ssh user to `{0}`'.format(ssh_user))
-        env.profile.ssh_user = ssh_user
-    if ssh_key:
-        logger.info('Setting ssh key to `{0}`'.format(ssh_key))
-        env.profile.ssh_key = ssh_key
-    if ssh_port:
-        logger.info('Setting ssh port to `{0}`'.format(ssh_port))
-        env.profile.ssh_port = ssh_port
-    if kerberos_env is not None:
-        logger.info('Setting kerberos_env to `{0}`'.format(kerberos_env))
-        env.profile.kerberos_env = kerberos_env
-    if ssl is not None:
-        _set_profile_ssl(ssl, rest_port, logger)
-
-    env.profile.save()
-    if old_name is not None:
-        env.set_active_profile(profile_name)
-        env.delete_profile(old_name)
-    logger.info('Settings saved successfully')
-
-
 def _set_profile_ssl(ssl, rest_port, logger):
     if ssl is None:
         raise CloudifyCliError('Internal error: SSL must be either `on` or '
@@ -412,12 +326,12 @@ def _set_profile_ssl(ssl, rest_port, logger):
         for node in manager_cluster:
             node['rest_port'] = port
             node['rest_protocol'] = protocol
-            logger.info('Enabling SSL for {0}'.format(node['host_ip']))
+            logger.info('Enabling SSL for %(host_ip)s', node)
             if not node.get('cert'):
                 missing_certs.append(node['hostname'])
         if missing_certs:
             logger.warning('The following cluster nodes have no certificate '
-                           'set: {0}'.format(', '.join(missing_certs)))
+                           'set: %s', ', '.join(missing_certs))
             logger.warning('If required, set the certificates for those '
                            'nodes using `cfy profiles set-cluster`')
 
@@ -426,6 +340,7 @@ def _set_profile_ssl(ssl, rest_port, logger):
     name='set',
     short_help='Set name/manager username/password/tenant in current profile')
 @cfy.options.profile_name
+@cfy.options.profile_manager_ip
 @cfy.options.manager_username
 @cfy.options.manager_password
 @cfy.options.manager_tenant()
@@ -440,6 +355,7 @@ def _set_profile_ssl(ssl, rest_port, logger):
 @cfy.options.common_options
 @cfy.pass_logger
 def set_cmd(profile_name,
+            manager_ip,
             manager_username,
             manager_password,
             manager_tenant,
@@ -452,19 +368,81 @@ def set_cmd(profile_name,
             kerberos_env,
             skip_credentials_validation,
             logger):
-    return set_profile(profile_name,
-                       manager_username,
-                       manager_password,
-                       manager_tenant,
-                       ssh_user,
-                       ssh_key,
-                       ssh_port,
-                       _get_ssl_indication(ssl),
-                       rest_certificate,
-                       rest_port,
-                       get_kerberos_indication(kerberos_env),
-                       skip_credentials_validation,
-                       logger)
+    """Set the profile name, manager username and/or password and/or tenant
+    and/or ssl state (on/off) in the *current* profile
+    """
+    if not any([profile_name, manager_ip, ssh_user, ssh_key, ssh_port,
+                manager_username, manager_password, manager_tenant,
+                ssl is not None, rest_certificate, kerberos_env is not None]):
+        raise CloudifyCliError(
+            "You must supply at least one of the following:  "
+            "profile name, username, password, tenant, "
+            "ssl, rest certificate, ssh user, ssh key, ssh port, kerberos env")
+    username = manager_username or env.get_username()
+    password = manager_password or env.get_password()
+    tenant = manager_tenant or env.get_tenant_name()
+    protocol, port = _get_ssl_protocol_and_port(ssl)
+    if rest_port is not None:
+        port = rest_port
+
+    if not skip_credentials_validation:
+        _validate_credentials(manager_ip,
+                              username,
+                              password,
+                              tenant,
+                              rest_certificate,
+                              protocol,
+                              port,
+                              kerberos_env)
+    old_name = None
+    if profile_name:
+        if profile_name == 'local':
+            raise CloudifyCliError('Cannot use the reserved name "local"')
+        if env.is_profile_exists(profile_name):
+            raise CloudifyCliError('Profile {0} already exists'
+                                   .format(profile_name))
+        old_name = env.profile.profile_name
+        env.profile.profile_name = profile_name
+    if manager_ip:
+        env.profile.manager_ip = manager_ip
+        logger.info('Setting the manager address to `%s`', manager_ip)
+    if manager_username:
+        logger.info('Setting username to `%s`', manager_username)
+        env.profile.manager_username = manager_username
+    if manager_password:
+        logger.info('Setting password to `%s`', manager_password)
+        env.profile.manager_password = manager_password
+    if manager_tenant:
+        logger.info('Setting tenant to `%s`', manager_tenant)
+        env.profile.manager_tenant = manager_tenant
+    if rest_certificate:
+        logger.info('Setting rest certificate to `%s`', rest_certificate)
+        env.profile.rest_certificate = rest_certificate
+    if rest_port:
+        logger.info('Setting rest port to `%s', rest_port)
+        env.profile.rest_port = rest_port
+    if ssh_user:
+        logger.info('Setting ssh user to `%s`', ssh_user)
+        env.profile.ssh_user = ssh_user
+    if ssh_key:
+        logger.info('Setting ssh key to `%s`', ssh_key)
+        env.profile.ssh_key = ssh_key
+    if ssh_port:
+        logger.info('Setting ssh port to `%s`', ssh_port)
+        env.profile.ssh_port = ssh_port
+    if kerberos_env is not None:
+        logger.info('Setting kerberos_env to `%s`', kerberos_env)
+        env.profile.kerberos_env = kerberos_env
+    if ssl is not None:
+        _set_profile_ssl(ssl, rest_port, logger)
+
+    env.profile.save()
+    if old_name is not None:
+        env.set_active_profile(profile_name)
+        env.delete_profile(old_name)
+    logger.info('Settings saved successfully')
+    if not skip_credentials_validation:
+        _update_cluster_profile_to_dict(logger)
 
 
 @profiles.command(
@@ -511,15 +489,14 @@ def set_cluster(cluster_node_name,
     ]:
         if source:
             changed_node[target] = source
-            logger.info('Node {0}: setting {1} to `{2}`'
-                        .format(cluster_node_name, label, source))
+            logger.info('Node %s: setting %s to `%s`',
+                        cluster_node_name, label, source)
     if rest_certificate:
         changed_node['cert'] = rest_certificate
         changed_node['trust_all'] = False
         changed_node['rest_protocol'] = 'https'
-        logger.info('Node {0}: setting rest-certificate to `{1}` and enabling '
-                    'certificate verification'
-                    .format(cluster_node_name, source))
+        logger.info('Node %s: setting rest-certificate to `%s` and enabling '
+                    'certificate verification', cluster_node_name, source)
     env.profile.save()
     logger.info('Settings saved successfully')
 
@@ -573,7 +550,8 @@ def unset(manager_username,
         cert = None
 
     if not skip_credentials_validation:
-        _validate_credentials(username,
+        _validate_credentials(env.profile.manager_ip,
+                              username,
                               password,
                               tenant,
                               cert,
@@ -628,7 +606,7 @@ def export_profiles(include_keys, output_path, logger):
         os.path.join(os.getcwd(), 'cfy-profiles.tar.gz')
 
     # TODO: Copy exported ssh keys to each profile's directory
-    logger.info('Exporting profiles to {0}...'.format(destination))
+    logger.info('Exporting profiles to %s...', destination)
     if include_keys:
         for profile in env.get_profile_names():
             _backup_ssh_key(profile)
@@ -658,7 +636,7 @@ def import_profiles(archive_path, include_keys, logger):
     _assert_is_tarfile(archive_path)
     _assert_profiles_archive(archive_path)
 
-    logger.info('Importing profiles from {0}...'.format(archive_path))
+    logger.info('Importing profiles from %s...', archive_path)
     utils.untar(archive_path, os.path.dirname(env.PROFILES_DIR))
 
     if include_keys:
@@ -669,8 +647,8 @@ def import_profiles(archive_path, include_keys, logger):
             logger.info("The profiles archive you provided contains ssh keys "
                         "for one or more profiles. To restore those keys to "
                         "their original locations, you can use the "
-                        "`--include-keys flag or copy them manually from {0} "
-                        .format(EXPORTED_SSH_KEYS_DIR))
+                        "`--include-keys flag or copy them manually from %s ",
+                        EXPORTED_SSH_KEYS_DIR)
     logger.info('Import complete!')
     logger.info('You can list profiles using `cfy profiles list`')
 
@@ -716,14 +694,13 @@ def _move_ssh_key(profile, logger, is_backup):
         if is_backup:
             if not os.path.isdir(EXPORTED_SSH_KEYS_DIR):
                 os.makedirs(EXPORTED_SSH_KEYS_DIR)
-            logger.info('Copying ssh key {0} to {1}...'.format(
-                key_filepath, backup_path))
+            logger.info('Copying ssh key %s to %s...',
+                        key_filepath, backup_path)
             shutil.copy2(key_filepath, backup_path)
         else:
             if os.path.isfile(backup_path):
-                logger.info(
-                    'Restoring ssh key for profile {0} to {1}...'.format(
-                        profile, key_filepath))
+                logger.info('Restoring ssh key for profile %s to %s...',
+                            profile, key_filepath)
                 shutil.move(backup_path, key_filepath)
 
 
@@ -872,12 +849,6 @@ def _is_manager_secured(response_history):
     return False
 
 
-def _get_ssl_indication(ssl):
-    if ssl is None:
-        return None
-    return str(ssl).lower() == 'on'
-
-
 def _get_ssl_protocol_and_port(ssl):
     if ssl is not None:
         protocol, port = (constants.SECURED_REST_PROTOCOL,
@@ -889,11 +860,12 @@ def _get_ssl_protocol_and_port(ssl):
 
 
 @cfy.pass_logger
-def _validate_credentials(username, password, tenant, certificate, protocol,
-                          rest_port, kerberos_env, logger):
+def _validate_credentials(manager_ip, username, password, tenant, certificate,
+                          protocol, rest_port, kerberos_env, logger):
     logger.info('Validating credentials...')
     _get_client_and_assert_manager(
         profile_name=env.profile.profile_name,
+        manager_ip=manager_ip,
         manager_username=username,
         manager_password=password,
         manager_tenant=tenant,
